
# Micro - Servicio

Micro-servicio auto generado.

# Instalación
```bash
apt install python-venv
pip install -g bws-boa

boa init .
boa install

cat .env > .env.dev
```

# Desarrollo

```bash
boa web --dev
```
